@@ -2,10 +2,11 @@
 /*!	\file filledrect.cpp
 **	\brief Implementation of the "Rectangle" layer
 **
-**	$Id: filledrect.cpp 1191 2007-12-10 01:58:46Z dooglus $
+**	$Id: filledrect.cpp 2095 2008-10-13 23:13:07Z genete $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -56,7 +57,7 @@ SYNFIG_LAYER_SET_NAME(FilledRect,"rectangle");
 SYNFIG_LAYER_SET_LOCAL_NAME(FilledRect,N_("Rectangle"));
 SYNFIG_LAYER_SET_CATEGORY(FilledRect,N_("Geometry"));
 SYNFIG_LAYER_SET_VERSION(FilledRect,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(FilledRect,"$Id: filledrect.cpp 1191 2007-12-10 01:58:46Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(FilledRect,"$Id: filledrect.cpp 2095 2008-10-13 23:13:07Z genete $");
 
 /* === P R O C E D U R E S ================================================= */
 
@@ -82,8 +83,8 @@ FilledRect::set_param(const String & param, const ValueBase &value)
 	IMPORT(color);
 	IMPORT(point1);
 	IMPORT(point2);
-	IMPORT(feather_x);
-	IMPORT(feather_y);
+	IMPORT_PLUS(feather_x, if(feather_x<0)feather_x=0;);
+	IMPORT_PLUS(feather_y, if(feather_y<0)feather_y=0;);
 	IMPORT(bevel);
 	IMPORT(bevCircle);
 
