@@ -2,7 +2,7 @@
 /*!	\file lyr_freetype.h
 **	\brief Header file for implementation of the "Text" layer
 **
-**	$Id: lyr_freetype.h 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id: lyr_freetype.h 2013 2008-04-11 12:46:43Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -119,7 +119,7 @@ private:
 	synfig::Vector size;
 	synfig::Vector orient;
 	synfig::Color color;
-	synfig::Point pos;
+	synfig::Point origin;
 	synfig::Real compress;
 	synfig::Real vcompress;
 
