@@ -2,7 +2,7 @@
 /*!	\file rotate.cpp
 **	\brief Implementation of the "Rotate" layer
 **
-**	$Id: rotate.cpp 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id: rotate.cpp 2093 2008-10-11 07:00:30Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -55,7 +55,7 @@ SYNFIG_LAYER_SET_NAME(Rotate,"rotate");
 SYNFIG_LAYER_SET_LOCAL_NAME(Rotate,N_("Rotate"));
 SYNFIG_LAYER_SET_CATEGORY(Rotate,N_("Transform"));
 SYNFIG_LAYER_SET_VERSION(Rotate,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(Rotate,"$Id: rotate.cpp 1643 2008-02-09 19:12:18Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Rotate,"$Id: rotate.cpp 2093 2008-10-11 07:00:30Z dooglus $");
 
 /* === P R O C E D U R E S ================================================= */
 
@@ -189,42 +189,50 @@ Rotate::accelerated_render(Context context,Surface *surface,int quality, const R
 
 	Point tl(renddesc.get_tl()-origin);
 	Point br(renddesc.get_br()-origin);
-	Point rot_tl(cos_val*tl[0]+sin_val*tl[1],-sin_val*tl[0]+cos_val*tl[1]);
-	Point rot_br(cos_val*br[0]+sin_val*br[1],-sin_val*br[0]+cos_val*br[1]);
-	Point rot_tr(cos_val*br[0]+sin_val*tl[1],-sin_val*br[0]+cos_val*tl[1]);
-	Point rot_bl(cos_val*tl[0]+sin_val*br[1],-sin_val*tl[0]+cos_val*br[1]);
-	rot_tl+=origin;
-	rot_br+=origin;
-	rot_tr+=origin;
-	rot_bl+=origin;
 
-	Point min_point(min(min(min(rot_tl[0],rot_br[0]),rot_tr[0]),rot_bl[0]),min(min(min(rot_tl[1],rot_br[1]),rot_tr[1]),rot_bl[1]));
-	Point max_point(max(max(max(rot_tl[0],rot_br[0]),rot_tr[0]),rot_bl[0]),max(max(max(rot_tl[1],rot_br[1]),rot_tr[1]),rot_bl[1]));
+	{
+		Point rot_tl(cos_val*tl[0]+sin_val*tl[1],-sin_val*tl[0]+cos_val*tl[1]);
+		Point rot_br(cos_val*br[0]+sin_val*br[1],-sin_val*br[0]+cos_val*br[1]);
+		Point rot_tr(cos_val*br[0]+sin_val*tl[1],-sin_val*br[0]+cos_val*tl[1]);
+		Point rot_bl(cos_val*tl[0]+sin_val*br[1],-sin_val*tl[0]+cos_val*br[1]);
+		rot_tl+=origin;
+		rot_br+=origin;
+		rot_tr+=origin;
+		rot_bl+=origin;
 
-	if(tl[0]>br[0])
-	{
-		tl[0]=max_point[0];
-		br[0]=min_point[0];
-	}
-	else
-	{
-		br[0]=max_point[0];
-		tl[0]=min_point[0];
-	}
-	if(tl[1]>br[1])
-	{
-		tl[1]=max_point[1];
-		br[1]=min_point[1];
-	}
-	else
-	{
-		br[1]=max_point[1];
-		tl[1]=min_point[1];
+		Point min_point(min(min(min(rot_tl[0],rot_br[0]),rot_tr[0]),rot_bl[0]),min(min(min(rot_tl[1],rot_br[1]),rot_tr[1]),rot_bl[1]));
+		Point max_point(max(max(max(rot_tl[0],rot_br[0]),rot_tr[0]),rot_bl[0]),max(max(max(rot_tl[1],rot_br[1]),rot_tr[1]),rot_bl[1]));
+
+		if(tl[0]>br[0])
+		{
+			tl[0]=max_point[0];
+			br[0]=min_point[0];
+		}
+		else
+		{
+			br[0]=max_point[0];
+			tl[0]=min_point[0];
+		}
+		if(tl[1]>br[1])
+		{
+			tl[1]=max_point[1];
+			br[1]=min_point[1];
+		}
+		else
+		{
+			br[1]=max_point[1];
+			tl[1]=min_point[1];
+		}
 	}
 
 	Real pw=(renddesc.get_w())/(renddesc.get_br()[0]-renddesc.get_tl()[0]);
 	Real ph=(renddesc.get_h())/(renddesc.get_br()[1]-renddesc.get_tl()[1]);
 
+	// we're going to round the canvas size to an integer number of pixels, so round the
+	// tl-br rectangle accordingly - otherwise we see the jittering described in bug 2152666
+	br[0] -= (pw*(br[0]-tl[0]) - round_to_int(pw*(br[0]-tl[0]))) / pw;
+	br[1] -= (ph*(br[1]-tl[1]) - round_to_int(ph*(br[1]-tl[1]))) / ph;
+
 	RendDesc desc(renddesc);
 	desc.clear_flags();
 	//desc.set_flags(RendDesc::PX_ASPECT);
