@@ -2,7 +2,7 @@
 /*!	\file shade.h
 **	\brief Header file for implementation of the "Shade" layer
 **
-**	$Id: shade.h 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id: shade.h 2014 2008-04-11 14:01:00Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -44,7 +44,7 @@ private:
 	synfig::Vector 	size;
 	int				type;
 	synfig::Color	color;
-	synfig::Vector	offset;
+	synfig::Vector	origin;
 	bool invert;
 
 public:
