@@ -2,11 +2,11 @@
 /*!	\file xorpattern.cpp
 **	\brief Implementation of the "XOR Pattern" layer
 **
-**	$Id: xorpattern.cpp 1191 2007-12-10 01:58:46Z dooglus $
+**	$Id: xorpattern.cpp 2095 2008-10-13 23:13:07Z genete $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007-2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -54,7 +54,7 @@ SYNFIG_LAYER_SET_NAME(XORPattern,"xor_pattern");
 SYNFIG_LAYER_SET_LOCAL_NAME(XORPattern,N_("XOR Pattern"));
 SYNFIG_LAYER_SET_CATEGORY(XORPattern,N_("Other"));
 SYNFIG_LAYER_SET_VERSION(XORPattern,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(XORPattern,"$Id: xorpattern.cpp 1191 2007-12-10 01:58:46Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(XORPattern,"$Id: xorpattern.cpp 2095 2008-10-13 23:13:07Z genete $");
 
 /* === P R O C E D U R E S ================================================= */
 
@@ -62,7 +62,7 @@ SYNFIG_LAYER_SET_CVS_ID(XORPattern,"$Id: xorpattern.cpp 1191 2007-12-10 01:58:46
 
 XORPattern::XORPattern():
 	Layer_Composite	(1.0,Color::BLEND_STRAIGHT),
-	pos(0.125,0.125),
+	origin(0.125,0.125),
 	size(0.25,0.25)
 {
 }
@@ -70,16 +70,18 @@ XORPattern::XORPattern():
 bool
 XORPattern::set_param(const String & param, const ValueBase &value)
 {
-	IMPORT(pos);
+	IMPORT(origin);
 	IMPORT(size);
 
+	IMPORT_AS(origin,"pos");
+
 	return Layer_Composite::set_param(param,value);
 }
 
 ValueBase
 XORPattern::get_param(const String & param)const
 {
-	EXPORT(pos);
+	EXPORT(origin);
 	EXPORT(size);
 
 	EXPORT_NAME();
@@ -94,7 +96,7 @@ XORPattern::get_color(Context context, const Point &point)const
 	if(get_amount()==0.0)
 		return context.get_color(point);
 
-	unsigned int a=(unsigned int)floor((point[0]-pos[0])/size[0]), b=(unsigned int)floor((point[1]-pos[1])/size[1]);
+	unsigned int a=(unsigned int)floor((point[0]-origin[0])/size[0]), b=(unsigned int)floor((point[1]-origin[1])/size[1]);
 	unsigned char rindex=(a^b);
 	unsigned char gindex=(a^(~b))*4;
 	unsigned char bindex=~(a^b)*2;
@@ -116,12 +118,12 @@ XORPattern::get_param_vocab()const
 {
 	Layer::Vocab ret(Layer_Composite::get_param_vocab());
 
-	ret.push_back(ParamDesc("pos")
-		.set_local_name(_("Offset"))
+	ret.push_back(ParamDesc("origin")
+		.set_local_name(_("Origin"))
 	);
 	ret.push_back(ParamDesc("size")
 		.set_local_name(_("Size"))
-		.set_origin("pos")
+		.set_origin("origin")
 	);
 
 	return ret;
