@@ -2,11 +2,11 @@
 /*!	\file xorpattern.h
 **	\brief Header file for implementation of the "XOR Pattern" layer
 **
-**	$Id: xorpattern.h 1192 2007-12-10 02:01:25Z dooglus $
+**	$Id: xorpattern.h 2095 2008-10-13 23:13:07Z genete $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007-2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -51,7 +51,7 @@ class XORPattern : public synfig::Layer_Composite, public synfig::Layer_NoDeform
 
 private:
 
-	Point pos;
+	Point origin;
 	Point size;
 
 public:
