@@ -1,8 +1,8 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file zoom.cpp
-**	\brief writeme
+**	\brief Implementation of the "Zoom" layer
 **
-**	$Id: zoom.cpp 377 2007-03-23 21:06:51Z dooglus $
+**	$Id: zoom.cpp 1191 2007-12-10 01:58:46Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -48,10 +48,10 @@
 
 SYNFIG_LAYER_INIT(Zoom);
 SYNFIG_LAYER_SET_NAME(Zoom,"zoom");
-SYNFIG_LAYER_SET_LOCAL_NAME(Zoom,_("Zoom"));
-SYNFIG_LAYER_SET_CATEGORY(Zoom,_("Transform"));
+SYNFIG_LAYER_SET_LOCAL_NAME(Zoom,N_("Zoom"));
+SYNFIG_LAYER_SET_CATEGORY(Zoom,N_("Transform"));
 SYNFIG_LAYER_SET_VERSION(Zoom,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(Zoom,"$Id: zoom.cpp 377 2007-03-23 21:06:51Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Zoom,"$Id: zoom.cpp 1191 2007-12-10 01:58:46Z dooglus $");
 
 /* === P R O C E D U R E S ================================================= */
 
