@@ -1,11 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file mod_filter/blur.h
-**	\brief Template Header
+**	\brief Header file for implementation of the "Blur" layer
 **
-**	$Id: blur.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: blur.h 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -56,6 +57,8 @@ public:
 	virtual synfig::Rect get_full_bounding_rect(Context context)const;
 
 	virtual Vocab get_param_vocab()const;
+
+	virtual bool reads_context()const { return true; }
 }; // END of class Blur
 
 /* -- E X T E R N S --------------------------------------------------------- */
