@@ -2,10 +2,11 @@
 /*!	\file halftone.cpp
 **	\brief blehh
 **
-**	$Id: halftone.cpp 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: halftone.cpp 2095 2008-10-13 23:13:07Z genete $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -88,7 +89,7 @@ Halftone::mask(synfig::Point point)const
 	float radius1;
 	float radius2;
 
-	point-=offset;
+	point-=origin;
 
 	{
 		const float	a(Angle::sin(-angle).get()),	b(Angle::cos(-angle).get());
