@@ -2,10 +2,11 @@
 /*!	\file halftone.h
 **	\brief Template Header
 **
-**	$Id: halftone.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: halftone.h 2095 2008-10-13 23:13:07Z genete $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -47,7 +48,7 @@ class Halftone
 public:
 
 	int type;
-	synfig::Point offset;
+	synfig::Point origin;
 	synfig::Vector size;
 	synfig::Angle angle;
 
