@@ -1,11 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file halftone2.h
-**	\brief Template Header
+**	\brief Header file for implementation of the "Halftone 2" layer
 **
-**	$Id: halftone2.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: halftone2.h 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -64,9 +65,9 @@ public:
 	virtual synfig::Color get_color(synfig::Context context, const synfig::Point &pos)const;
 	virtual bool accelerated_render(synfig::Context context,synfig::Surface *surface,int quality, const synfig::RendDesc &renddesc, synfig::ProgressCallback *cb)const;
 	synfig::Layer::Handle hit_check(synfig::Context context, const synfig::Point &point)const;
-
 	virtual Vocab get_param_vocab()const;
-};
+	virtual bool reads_context()const { return true; }
+}; // END of class Halftone2
 
 /* === E N D =============================================================== */
 
