@@ -2,10 +2,11 @@
 /*!	\file circle.h
 **	\brief Header file for implementation of the "Circle" layer
 **
-**	$Id: circle.h 1192 2007-12-10 02:01:25Z dooglus $
+**	$Id: circle.h 2095 2008-10-13 23:13:07Z genete $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -46,7 +47,7 @@ class Circle : public synfig::Layer_Composite, public synfig::Layer_NoDeform
 	SYNFIG_LAYER_MODULE_EXT
 private:
 	synfig::Color color;
-	synfig::Point pos;
+	synfig::Point origin;
 	synfig::Real radius;
 	synfig::Real feather;
 	bool invert;
