@@ -2,11 +2,11 @@
 /*!	\file outline.cpp
 **	\brief Implementation of the "Outline" layer
 **
-**	$Id: outline.cpp 1697 2008-02-15 13:55:34Z dooglus $
+**	$Id: outline.cpp 2095 2008-10-13 23:13:07Z genete $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -70,7 +70,7 @@ SYNFIG_LAYER_SET_NAME(Outline,"outline");
 SYNFIG_LAYER_SET_LOCAL_NAME(Outline,N_("Outline"));
 SYNFIG_LAYER_SET_CATEGORY(Outline,N_("Geometry"));
 SYNFIG_LAYER_SET_VERSION(Outline,"0.2");
-SYNFIG_LAYER_SET_CVS_ID(Outline,"$Id: outline.cpp 1697 2008-02-15 13:55:34Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Outline,"$Id: outline.cpp 2095 2008-10-13 23:13:07Z genete $");
 
 /* === P R O C E D U R E S ================================================= */
 
@@ -183,6 +183,14 @@ Outline::sync()
 #if 1
 
 	const bool loop(bline.get_loop());
+
+	ValueNode_BLine::Handle bline_valuenode;
+	if (bline.get_contained_type() == ValueBase::TYPE_SEGMENT)
+	{
+		bline_valuenode = ValueNode_BLine::create(bline);
+		bline = (*bline_valuenode)(0);
+	}
+
 	const vector<synfig::BLinePoint> bline_(bline.get_list().begin(),bline.get_list().end());
 #define bline bline_
 
@@ -797,7 +805,7 @@ Outline::get_param_vocab()const
 
 	ret.push_back(ParamDesc("bline")
 		.set_local_name(_("Vertices"))
-		.set_origin("offset")
+		.set_origin("origin")
 		.set_hint("width")
 		.set_description(_("A list of BLine Points"))
 	);
