@@ -2,7 +2,7 @@
 /*!	\file rectangle.cpp
 **	\brief Implementation of the "Rectangle" layer
 **
-**	$Id: rectangle.cpp 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id: rectangle.cpp 2063 2008-09-20 15:46:33Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002 Robert B. Quattlebaum Jr.
@@ -58,7 +58,7 @@ SYNFIG_LAYER_SET_NAME(Rectangle,"rectangle");
 SYNFIG_LAYER_SET_LOCAL_NAME(Rectangle,N_("Rectangle"));
 SYNFIG_LAYER_SET_CATEGORY(Rectangle,N_("Geometry"));
 SYNFIG_LAYER_SET_VERSION(Rectangle,"0.2");
-SYNFIG_LAYER_SET_CVS_ID(Rectangle,"$Id: rectangle.cpp 1643 2008-02-09 19:12:18Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Rectangle,"$Id: rectangle.cpp 2063 2008-09-20 15:46:33Z dooglus $");
 
 /* === P R O C E D U R E S ================================================= */
 
@@ -274,27 +274,26 @@ Rectangle::get_color(Context context, const Point &pos)const
 	if(	pos[0]<max[0] && pos[0]>min[0] &&
 		pos[1]<max[1] && pos[1]>min[1] )
 	{
+		// inside the expanded rectangle
 		if(invert)
-			return context.get_color(pos);
-		else
-		{
-			if(is_solid_color())
-				return color;
-			else
-				return Color::blend(color,context.get_color(pos),get_amount(),get_blend_method());
+			return Color::blend(Color::alpha(),context.get_color(pos),get_amount(),get_blend_method());
 
-		}
-	}
-
-	if(invert)
-	{
 		if(is_solid_color())
 			return color;
-		else
-			return Color::blend(color,context.get_color(pos),get_amount(),get_blend_method());
-	}
 
-	return context.get_color(pos);
+		return Color::blend(color,context.get_color(pos),get_amount(),get_blend_method());
+	}
+	else
+	{
+		// outside the expanded rectangle
+		if(!invert)
+			return Color::blend(Color::alpha(),context.get_color(pos),get_amount(),get_blend_method());
+
+		if(is_solid_color())
+			return color;
+
+		return Color::blend(color,context.get_color(pos),get_amount(),get_blend_method());
+	}
 }
 
 bool
