@@ -2,11 +2,11 @@
 /*!	\file region.cpp
 **	\brief Implementation of the "Region" layer
 **
-**	$Id: region.cpp 1191 2007-12-10 01:58:46Z dooglus $
+**	$Id: region.cpp 2095 2008-10-13 23:13:07Z genete $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -63,7 +63,7 @@ SYNFIG_LAYER_SET_NAME(Region,"region");
 SYNFIG_LAYER_SET_LOCAL_NAME(Region,N_("Region"));
 SYNFIG_LAYER_SET_CATEGORY(Region,N_("Geometry"));
 SYNFIG_LAYER_SET_VERSION(Region,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(Region,"$Id: region.cpp 1191 2007-12-10 01:58:46Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Region,"$Id: region.cpp 2095 2008-10-13 23:13:07Z genete $");
 
 /* === P R O C E D U R E S ================================================= */
 
@@ -94,9 +94,9 @@ void
 Region::sync()
 {
 	if(bline.get_contained_type()==ValueBase::TYPE_BLINEPOINT)
-	{
 		segment_list=convert_bline_to_segment_list(bline);
-	}
+	else if(bline.get_contained_type()==ValueBase::TYPE_SEGMENT)
+		segment_list=vector<synfig::Segment>(bline.get_list().begin(), bline.get_list().end());
 	else
 	{
 		synfig::warning("Region: incorrect type on bline, layer disabled");
@@ -230,7 +230,7 @@ Region::get_param_vocab()const
 
 	ret.push_back(ParamDesc("bline")
 		.set_local_name(_("Vertices"))
-		.set_origin("offset")
+		.set_origin("origin")
 	);
 
 	return ret;
