@@ -2,11 +2,11 @@
 /*!	\file star.cpp
 **	\brief Implementation of the "Star" layer
 **
-**	$Id: star.cpp 1642 2008-02-09 18:25:35Z dooglus $
+**	$Id: star.cpp 2095 2008-10-13 23:13:07Z genete $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007-2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -62,7 +62,7 @@ SYNFIG_LAYER_SET_NAME(Star,"star");
 SYNFIG_LAYER_SET_LOCAL_NAME(Star,N_("Star"));
 SYNFIG_LAYER_SET_CATEGORY(Star,N_("Geometry"));
 SYNFIG_LAYER_SET_VERSION(Star,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(Star,"$Id: star.cpp 1642 2008-02-09 18:25:35Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Star,"$Id: star.cpp 2095 2008-10-13 23:13:07Z genete $");
 
 /* === P R O C E D U R E S ================================================= */
 
@@ -174,20 +174,20 @@ Star::get_param_vocab()const
 		.set_local_name(_("Outer Radius"))
 		.set_description(_("The radius of the outer points in the star"))
 		.set_is_distance()
-		.set_origin("offset")
+		.set_origin("origin")
 	);
 
 	ret.push_back(ParamDesc("radius2")
 		.set_local_name(_("Inner Radius"))
 		.set_description(_("The radius of the inner points in the star"))
 		.set_is_distance()
-		.set_origin("offset")
+		.set_origin("origin")
 	);
 
 	ret.push_back(ParamDesc("angle")
 		.set_local_name(_("Angle"))
 		.set_description(_("The orientation of the star"))
-		.set_origin("offset")
+		.set_origin("origin")
 	);
 
 	ret.push_back(ParamDesc("points")
