@@ -2,11 +2,11 @@
 /*!	\file curvegradient.h
 **	\brief Header file for implementation of the "Curve Gradient" layer
 **
-**	$Id: curvegradient.h 1192 2007-12-10 02:01:25Z dooglus $
+**	$Id: curvegradient.h 2095 2008-10-13 23:13:07Z genete $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007-2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -52,7 +52,7 @@ class CurveGradient : public Layer_Composite, public Layer_NoDeform
 private:
 	std::vector<synfig::BLinePoint> bline;
 
-	Point offset;
+	Point origin;
 	Real width;
 	Gradient gradient;
 	Real curve_length_;
