@@ -2,7 +2,7 @@
 /*!	\file plant.h
 **	\brief Header file for implementation of the "Plant" layer
 **
-**	$Id: plant.h 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id: plant.h 2014 2008-04-11 14:01:00Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -57,7 +57,7 @@ private:
 	std::vector<synfig::BLinePoint> bline;
 	bool bline_loop;
 
-	Point offset;
+	Point origin;
 
 	synfig::Gradient gradient;
 
