@@ -2,10 +2,11 @@
 /*!	\file interpolation.h
 **	\brief Template Header
 **
-**	$Id: interpolation.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: interpolation.h 2095 2008-10-13 23:13:07Z genete $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -37,13 +38,13 @@ namespace synfig {
 
 enum Interpolation
 {
-	INTERPOLATION_TCB,
-	INTERPOLATION_CONSTANT,
-	INTERPOLATION_LINEAR,
-	INTERPOLATION_HALT,
-	INTERPOLATION_MANUAL,
-	INTERPOLATION_UNDEFINED,
-	INTERPOLATION_NIL
+	INTERPOLATION_TCB,			// 0
+	INTERPOLATION_CONSTANT,		// 1
+	INTERPOLATION_LINEAR,		// 2
+	INTERPOLATION_HALT,			// 3
+	INTERPOLATION_MANUAL,		// 4
+	INTERPOLATION_UNDEFINED,	// 5
+	INTERPOLATION_NIL			// 6
 }; // END enum Interpolation
 
 }; // END of namespace synfig
