@@ -1,12 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file layer_motionblur.cpp
-**	\brief Template Header
+**	\brief Implementation of the "Motion Blur" layer
 **
-**	$Id: layer_motionblur.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: layer_motionblur.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -53,10 +53,10 @@ using namespace std;
 
 SYNFIG_LAYER_INIT(Layer_MotionBlur);
 SYNFIG_LAYER_SET_NAME(Layer_MotionBlur,"MotionBlur"); // todo: use motion_blur
-SYNFIG_LAYER_SET_LOCAL_NAME(Layer_MotionBlur,_("Motion Blur"));
-SYNFIG_LAYER_SET_CATEGORY(Layer_MotionBlur,_("Blurs"));
+SYNFIG_LAYER_SET_LOCAL_NAME(Layer_MotionBlur,N_("Motion Blur"));
+SYNFIG_LAYER_SET_CATEGORY(Layer_MotionBlur,N_("Blurs"));
 SYNFIG_LAYER_SET_VERSION(Layer_MotionBlur,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(Layer_MotionBlur,"$Id: layer_motionblur.cpp 848 2007-10-06 02:25:36Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Layer_MotionBlur,"$Id: layer_motionblur.cpp 1643 2008-02-09 19:12:18Z dooglus $");
 
 /* === M E M B E R S ======================================================= */
 
@@ -161,11 +161,11 @@ Layer_MotionBlur::accelerated_render(Context context,Surface *surface,int qualit
 				samples=3;
 				break;
 			case 9:
-				samples=3;
+				samples=2;
 				break;
 			case 10: // Rough Quality
             default:
-				samples=2;
+				samples=1;
 				break;
 
 		}
