@@ -2,7 +2,7 @@
 /*!	\file layer_pastecanvas.cpp
 **	\brief Implementation of the "Paste Canvas" layer
 **
-**	$Id: layer_pastecanvas.cpp 1753 2008-02-19 00:52:56Z dooglus $
+**	$Id: layer_pastecanvas.cpp 2060 2008-09-19 16:13:02Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -77,7 +77,7 @@ SYNFIG_LAYER_SET_NAME(Layer_PasteCanvas,"PasteCanvas"); // todo: use paste_canva
 SYNFIG_LAYER_SET_LOCAL_NAME(Layer_PasteCanvas,N_("Paste Canvas"));
 SYNFIG_LAYER_SET_CATEGORY(Layer_PasteCanvas,N_("Other"));
 SYNFIG_LAYER_SET_VERSION(Layer_PasteCanvas,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(Layer_PasteCanvas,"$Id: layer_pastecanvas.cpp 1753 2008-02-19 00:52:56Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Layer_PasteCanvas,"$Id: layer_pastecanvas.cpp 2060 2008-09-19 16:13:02Z dooglus $");
 
 /* === M E T H O D S ======================================================= */
 
@@ -395,8 +395,10 @@ Layer_PasteCanvas::accelerated_render(Context context,Surface *surface,int quali
 
 	if (!etl::intersect(context.get_full_bounding_rect(),full_bounding_rect+origin))
 	{
-		// if there's no intersection between the context and our surface, and we're rendering 'onto', then we're done
-		if (Color::is_onto(blend_method)) return true;
+		// if there's no intersection between the context and our
+		// surface, and we're rendering 'onto', then we're done
+		if (Color::is_onto(blend_method) && !Color::is_straight(blend_method))
+			return true;
 
 		/* 'straight' is faster than 'composite' and has the same
 		 * effect if the affected area of the lower layer is
