@@ -2,10 +2,11 @@
 /*!	\file layer_polygon.cpp
 **	\brief Implementation of the "Polygon" layer
 **
-**	$Id: layer_polygon.cpp 1202 2007-12-15 09:58:33Z dooglus $
+**	$Id: layer_polygon.cpp 2095 2008-10-13 23:13:07Z genete $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -59,7 +60,7 @@ SYNFIG_LAYER_SET_NAME(Layer_Polygon,"polygon");
 SYNFIG_LAYER_SET_LOCAL_NAME(Layer_Polygon,N_("Polygon"));
 SYNFIG_LAYER_SET_CATEGORY(Layer_Polygon,N_("Geometry"));
 SYNFIG_LAYER_SET_VERSION(Layer_Polygon,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(Layer_Polygon,"$Id: layer_polygon.cpp 1202 2007-12-15 09:58:33Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Layer_Polygon,"$Id: layer_polygon.cpp 2095 2008-10-13 23:13:07Z genete $");
 
 /* === C L A S S E S ======================================================= */
 
@@ -169,7 +170,7 @@ Layer_Polygon::get_param_vocab()const
 
 	ret.push_back(ParamDesc("vector_list")
 		.set_local_name(_("Vector List"))
-		.set_origin("offset")
+		.set_origin("origin")
 	);
 
 	return ret;
