@@ -2,11 +2,11 @@
 /*!	\file layer_shape.h
 **	\brief Header file for implementation of the "Shape" layer
 **
-**	$Id: layer_shape.h 1192 2007-12-10 02:01:25Z dooglus $
+**	$Id: layer_shape.h 2095 2008-10-13 23:13:07Z genete $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007-2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -66,7 +66,7 @@ private:
 	//exported data
 	Color 					color;
 
-	Point 	offset;
+	Point 	origin;
 	bool	invert;
 	bool	antialias;
 
