@@ -1,8 +1,8 @@
 /* === S Y N F I G ========================================================= */
-/*!	\file module.cpp
+/*!	\file synfig/module.cpp
 **	\brief writeme
 **
-**	$Id: module.cpp,v 1.1.1.1 2005/01/04 01:23:14 darco Exp $
+**	$Id: module.cpp 335 2007-03-16 00:39:09Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -33,8 +33,12 @@
 
 #include "module.h"
 #include "general.h"
-#include <ltdl.h>
 #include <ETL/stringf>
+
+#ifndef USE_CF_BUNDLES
+#include <ltdl.h>
+#endif
+
 #endif
 
 /* === M A C R O S ========================================================= */
@@ -52,10 +56,11 @@ Module::Book *synfig::Module::book_;
 bool
 Module::subsys_init(const String &prefix)
 {
+#ifndef USE_CF_BUNDLES
 	#ifndef SYNFIG_LTDL_NO_STATIC
 	//LTDL_SET_PRELOADED_SYMBOLS();
 	#endif
-	
+
 	if(lt_dlinit())
 	{
 		error(_("Errors on lt_dlinit()"));
@@ -74,7 +79,7 @@ Module::subsys_init(const String &prefix)
 #endif
 	lt_dladdsearchdir("/usr/local/lib/synfig/modules");
 	lt_dladdsearchdir(".");
-	
+#endif
 	book_=new Book;
 	return true;
 }
@@ -83,8 +88,10 @@ bool
 Module::subsys_stop()
 {
 	delete book_;
-	
+
+#ifndef USE_CF_BUNDLES
 	lt_dlexit();
+#endif
 	return true;
 }
 
@@ -109,21 +116,22 @@ synfig::Module::Register(Module::Handle mod)
 bool
 synfig::Module::Register(const String &module_name, ProgressCallback *callback)
 {
+#ifndef USE_CF_BUNDLES
 	lt_dlhandle module;
 
 	if(callback)callback->task(strprintf(_("Attempting to register \"%s\""),module_name.c_str()));
 
 	module=lt_dlopenext((string("lib")+module_name).c_str());
 	if(!module)module=lt_dlopenext(module_name.c_str());
-	
+
 	if(!module)
 	{
-		if(callback)callback->error(strprintf(_("Unable to find module \"%s\" (%s)"),module_name.c_str(),lt_dlerror()));
+		if(callback)callback->warning(strprintf(_("Unable to find module \"%s\" (%s)"),module_name.c_str(),lt_dlerror()));
 		return false;
 	}
 
 	if(callback)callback->task(strprintf(_("Found module \"%s\""),module_name.c_str()));
-	
+
 	Module::constructor_type constructor=NULL;
 	Handle mod;
 
@@ -148,7 +156,7 @@ synfig::Module::Register(const String &module_name, ProgressCallback *callback)
 //		if(callback)callback->task(string("looking for -> lib")+module_name+"_LTX_new_instance()");
 		constructor=(Module::constructor_type )lt_dlsym(module,(string("_")+module_name+"_LTX_new_instance").c_str());
 	}
-	
+
 	if(constructor)
 	{
 //		if(callback)callback->task(strprintf("Executing callback for \"%s\"",module_name.c_str()));
@@ -174,6 +182,7 @@ synfig::Module::Register(const String &module_name, ProgressCallback *callback)
     }
 
 	if(callback)callback->task(strprintf(_("Success for \"%s\""),module_name.c_str()));
-	
+
+#endif
 	return false;
 }
