@@ -2,10 +2,11 @@
 /*!	\file polynomial_root.h
 **	\brief Polynomial Root Finder Header
 **
-**	$Id: polynomial_root.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: polynomial_root.h 1642 2008-02-09 18:25:35Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -42,11 +43,11 @@ public:
 
 	//Will maintain all lower constants
 	void degree(unsigned int d, const T & def = (T)0) { resize(d+1,def); }
-	unsigned int degree()const { return size() - 1; }
+	unsigned int degree()const { return this->size() - 1; }
 
 	const Polynomial & operator+=(const Polynomial &p)
 	{
-		if(p.size() > size())
+		if(p.size() > this->size())
 			resize(p.size(), (T)0);
 
 		for(int i = 0; i < p.size(); ++i)
@@ -58,7 +59,7 @@ public:
 
 	const Polynomial & operator-=(const Polynomial &p)
 	{
-		if(p.size() > size())
+		if(p.size() > this->size())
 			resize(p.size(), (T)0);
 
 		for(int i = 0; i < p.size(); ++i)
@@ -72,7 +73,7 @@ public:
 	{
 		if(p.size() < 1)
 		{
-			resize(0);
+			this->resize(0);
 			return *this;
 		}
 
@@ -87,7 +88,7 @@ public:
 
 		if(p.size() < 2) return *this;
 
-		resize(size() + p.degree());
+		this->resize(this->size() + p.degree());
 		for(int i = 0; i < nc.size(); ++i)
 		{
 			for(int j = 1; j < p.size(); ++j)
