@@ -2,7 +2,7 @@
 /*!	\file savecanvas.cpp
 **	\brief Writeme
 **
-**	$Id: savecanvas.cpp 1812 2008-02-24 20:50:18Z dooglus $
+**	$Id: savecanvas.cpp 1913 2008-03-13 23:46:03Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -333,8 +333,8 @@ xmlpp::Element* encode_animated(xmlpp::Element* root,ValueNode_Animated::ConstHa
 
 		if(iter->get_tension()!=0.0)
 			waypoint_node->set_attribute("tension",strprintf("%f",iter->get_tension()));
-		if(iter->get_time_tension()!=0.0)
-			waypoint_node->set_attribute("temporal-tension",strprintf("%f",iter->get_time_tension()));
+		if(iter->get_temporal_tension()!=0.0)
+			waypoint_node->set_attribute("temporal-tension",strprintf("%f",iter->get_temporal_tension()));
 		if(iter->get_continuity()!=0.0)
 			waypoint_node->set_attribute("continuity",strprintf("%f",iter->get_continuity()));
 		if(iter->get_bias()!=0.0)
@@ -427,19 +427,13 @@ xmlpp::Element* encode_dynamic_list(xmlpp::Element* root,ValueNode_DynamicList::
 				if(entry_iter->state==true)
 				{
 					if(entry_iter->priority)
-					{
-						printf("begin priority is %d\n", entry_iter->priority);
 						begin_sequence+=strprintf("p%d ",entry_iter->priority);
-					}
 					begin_sequence+=entry_iter->time.get_string(fps)+", ";
 				}
 				else
 				{
 					if(entry_iter->priority)
-					{
-						printf("end priority is %d\n", entry_iter->priority);
 						end_sequence+=strprintf("p%d ",entry_iter->priority);
-					}
 					end_sequence+=entry_iter->time.get_string(fps)+", ";
 				}
 
