@@ -2,10 +2,11 @@
 /*!	\file savecanvas.h
 **	\brief writeme
 **
-**	$Id: savecanvas.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: savecanvas.h 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -29,6 +30,7 @@
 
 #include "string.h"
 #include "canvas.h"
+#include "releases.h"
 
 /* === M A C R O S ========================================================= */
 
@@ -47,6 +49,9 @@ bool save_canvas(const String &filename, Canvas::ConstHandle canvas);
 //! Stores a Canvas in a string in XML format
 String canvas_to_string(Canvas::ConstHandle canvas);
 
+void set_file_version(ReleaseVersion version);
+ReleaseVersion get_file_version();
+
 }; // END of namespace synfig
 
 /* === E N D =============================================================== */
