@@ -2,7 +2,7 @@
 /*!	\file target.cpp
 **	\brief Target Class Implementation
 **
-**	$Id: target.cpp 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: target.cpp 1202 2007-12-15 09:58:33Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -95,7 +95,7 @@ Target::Target():
 }
 
 void
-synfig::Target::set_canvas(Canvas::Handle c)
+synfig::Target::set_canvas(etl::handle<Canvas> c)
 {
 	canvas=c;
 	RendDesc desc=canvas->rend_desc();
