@@ -2,11 +2,12 @@
 /*!	\file valuenode.cpp
 **	\brief Implementation of the "Placeholder" valuenode conversion.
 **
-**	$Id: valuenode.cpp 1708 2008-02-16 04:56:00Z dooglus $
+**	$Id: valuenode.cpp 2095 2008-10-13 23:13:07Z genete $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007, 2008 Chris Moore
+**  Copyright (c) 2008 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -72,6 +73,18 @@
 #include "valuenode_duplicate.h"
 #include "valuenode_integer.h"
 #include "valuenode_step.h"
+#include "valuenode_vectorangle.h"
+#include "valuenode_vectorlength.h"
+#include "valuenode_vectorx.h"
+#include "valuenode_vectory.h"
+#include "valuenode_gradientcolor.h"
+#include "valuenode_dotproduct.h"
+#include "valuenode_timestring.h"
+#include "valuenode_realstring.h"
+#include "valuenode_join.h"
+#include "valuenode_anglestring.h"
+#include "valuenode_intstring.h"
+#include "valuenode_log.h"
 
 #include "layer.h"
 
@@ -153,6 +166,19 @@ ValueNode::subsys_init()
 	ADD_VALUENODE(ValueNode_Step,			  "step",			  _("Step"),			 RELEASE_VERSION_0_61_08); // SVN r1691
 	ADD_VALUENODE(ValueNode_BLineCalcWidth,	  "blinecalcwidth",	  _("BLine Width"),		 RELEASE_VERSION_0_61_08); // SVN r1694
 
+	ADD_VALUENODE(ValueNode_VectorAngle,	  "vectorangle",	  _("Vector Angle"),	 RELEASE_VERSION_0_61_09); // SVN r1880
+	ADD_VALUENODE(ValueNode_VectorLength,	  "vectorlength",	  _("Vector Length"),	 RELEASE_VERSION_0_61_09); // SVN r1881
+	ADD_VALUENODE(ValueNode_VectorX,		  "vectorx",		  _("Vector X"),		 RELEASE_VERSION_0_61_09); // SVN r1882
+	ADD_VALUENODE(ValueNode_VectorY,		  "vectory",		  _("Vector Y"),		 RELEASE_VERSION_0_61_09); // SVN r1882
+	ADD_VALUENODE(ValueNode_GradientColor,	  "gradientcolor",	  _("Gradient Color"),	 RELEASE_VERSION_0_61_09); // SVN r1885
+	ADD_VALUENODE(ValueNode_DotProduct,		  "dotproduct",		  _("Dot Product"),		 RELEASE_VERSION_0_61_09); // SVN r1891
+	ADD_VALUENODE(ValueNode_TimeString,		  "timestring",		  _("Time String"),		 RELEASE_VERSION_0_61_09); // SVN r2000
+	ADD_VALUENODE(ValueNode_RealString,		  "realstring",		  _("Real String"),		 RELEASE_VERSION_0_61_09); // SVN r2003
+	ADD_VALUENODE(ValueNode_Join,			  "join",			  _("Joined List"),		 RELEASE_VERSION_0_61_09); // SVN r2007
+	ADD_VALUENODE(ValueNode_AngleString,	  "anglestring",	  _("Angle String"),	 RELEASE_VERSION_0_61_09); // SVN r2010
+	ADD_VALUENODE(ValueNode_IntString,		  "intstring",		  _("Int String"),		 RELEASE_VERSION_0_61_09); // SVN r2010
+	ADD_VALUENODE(ValueNode_Logarithm,		  "logarithm",		  _("Logarithm"),		 RELEASE_VERSION_0_61_09); // SVN r2034
+
 #undef ADD_VALUENODE
 #undef ADD_VALUENODE2
 
