@@ -2,7 +2,7 @@
 /*!	\file valuenode_animated.cpp
 **	\brief Implementation of the "Animated" valuenode conversion.
 **
-**	$Id: valuenode_animated.cpp 1809 2008-02-24 05:16:03Z pabs $
+**	$Id: valuenode_animated.cpp 1913 2008-03-13 23:46:03Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -491,8 +491,8 @@ public:
 			curve.first.set_rs(iter->get_time(), next->get_time());
 			curve.first.p1()=iter->get_time();
 			curve.first.p2()=next->get_time();
-			curve.first.t1()=(curve.first.p2()-curve.first.p1())*(1.0f-iter->get_time_tension());
-			curve.first.t2()=(curve.first.p2()-curve.first.p1())*(1.0f-next->get_time_tension());
+			curve.first.t1()=(curve.first.p2()-curve.first.p1())*(1.0f-iter->get_temporal_tension());
+			curve.first.t2()=(curve.first.p2()-curve.first.p1())*(1.0f-next->get_temporal_tension());
 
 
 			curve.first.sync();
