@@ -2,7 +2,7 @@
 /*!	\file valuenode_segcalctangent.cpp
 **	\brief Implementation of the "Segment Tangent" valuenode conversion.
 **
-**	$Id: valuenode_segcalctangent.cpp 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id: valuenode_segcalctangent.cpp 1857 2008-03-04 22:02:22Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -84,12 +84,7 @@ ValueNode_SegCalcTangent::operator()(Time t)const
 	etl::hermite<Vector> curve(segment.p1,segment.p2,segment.t1,segment.t2);
 	etl::derivative< etl::hermite<Vector> > deriv(curve);
 
-#ifdef ETL_FIXED_DERIVATIVE
-	return deriv((*amount_)(t).get(Real()))*(0.5);
-#else
-	return deriv((*amount_)(t).get(Real()))*(-0.5);
-#endif
-
+	return deriv((*amount_)(t).get(Real()));
 }
 
 
